Changelog
=========

0.0.7 (2011-09-15)
------------------
#. django-object-tools refactor.

0.0.6
-----
#. Tests, docs, cleanup, descending ordering, bugfixes.

0.0.5
-----
#. No longer use class_prepared signal.

0.0.4
-----
#.Initial public release.

